@@ -2,16 +2,16 @@
 # -*- coding: utf-8 -*-
 
 extensions = [
-    "sphinx.ext.autodoc",
-    "jaraco.packaging.sphinx",
-    "rst.linker",
-    "sphinx.ext.intersphinx",
+    'sphinx.ext.autodoc',
+    'jaraco.packaging.sphinx',
 ]
 
+master_doc = "index"
+
 pygments_style = "sphinx"
 
-intersphinx_mapping = {'python': ('http://docs.python.org/', None)}
-
+# Link dates and other references in the changelog
+extensions += ['rst.linker']
 link_files = {
     '../CHANGES.rst': dict(
         using=dict(GH='https://github.com'),
@@ -26,13 +26,23 @@ link_files = {
             ),
             dict(
                 pattern=r'PEP[- ](?P<pep_number>\d+)',
-                url='https://www.python.org/dev/peps/pep-{pep_number:0>4}/',
+                url='https://peps.python.org/pep-{pep_number:0>4}/',
             ),
         ],
     )
 }
 
-# Be strict about any broken references:
+# Be strict about any broken references
 nitpicky = True
 
+# Include Python intersphinx mapping to prevent failures
+# jaraco/skeleton#51
+extensions += ['sphinx.ext.intersphinx']
+intersphinx_mapping = {
+    'python': ('https://docs.python.org/3', None),
+}
+
+# Preserve authored syntax for defaults
+autodoc_preserve_defaults = True
+
 extensions += ['jaraco.tidelift']
