@@ -301,6 +301,7 @@ class TestBasics:
 
 
 class TestReadWriteText:
+    @pytest.mark.filterwarnings('ignore:Writing bytes in write_text')
     def test_read_write(self, tmpdir):
         file = path.Path(tmpdir) / 'filename'
         file.write_text('hello world')
@@ -546,36 +547,31 @@ class TestScratchDir:
                 with contextlib.suppress(Exception):
                     f.remove()
 
-    @pytest.mark.skipif(
-        platform.system() != "Linux",
-        reason="Only Linux allows writing invalid encodings",
-    )
-    def test_listdir_other_encoding(self, tmpdir):  # pragma: nocover
+    @pytest.fixture
+    def bytes_filename(self, tmpdir):
+        name = r'r\xe9\xf1emi'.encode('latin-1')
+        base = str(tmpdir).encode('ascii')
+        try:
+            with open(os.path.join(base, name), 'wb'):
+                pass
+        except Exception as exc:
+            raise pytest.skip(f"Invalid encodings disallowed {exc}")
+        return name
+
+    def test_listdir_other_encoding(self, tmpdir, bytes_filename):  # pragma: nocover
         """
         Some filesystems allow non-character sequences in path names.
         ``.listdir`` should still function in this case.
         See issue #61 for details.
         """
-        assert Path(tmpdir).listdir() == []
-        tmpdir_bytes = str(tmpdir).encode('ascii')
-
-        filename = 'r\xe9\xf1emi'.encode('latin-1')
-        pathname = os.path.join(tmpdir_bytes, filename)
-        with open(pathname, 'wb'):
-            pass
         # first demonstrate that os.listdir works
-        assert os.listdir(tmpdir_bytes)
+        assert os.listdir(str(tmpdir).encode('ascii'))
 
         # now try with path
         results = Path(tmpdir).listdir()
-        assert len(results) == 1
         (res,) = results
         assert isinstance(res, Path)
-        # OS X seems to encode the bytes in the filename as %XX characters.
-        if platform.system() == 'Darwin':
-            assert res.basename() == 'r%E9%F1emi'
-            return
-        assert len(res.basename()) == len(filename)
+        assert len(res.basename()) == len(bytes_filename)
 
     def test_makedirs(self, tmpdir):
         d = Path(tmpdir)
@@ -799,14 +795,16 @@ class TestScratchDir:
             expected = 2 * cleanNoHanging.replace('\n', eol).encode(encoding)
             assert p.bytes() == expected
 
-        testLinesep('\n')
-        testLinesep('\r')
-        testLinesep('\r\n')
-        testLinesep('\x0d\x85')
+        with pytest.deprecated_call():
+            testLinesep('\n')
+            testLinesep('\r')
+            testLinesep('\r\n')
+            testLinesep('\x0d\x85')
 
         # Again, but with linesep=None.
-        p.write_lines(givenLines, encoding, linesep=None)
-        p.write_lines(givenLines, encoding, linesep=None, append=True)
+        with pytest.deprecated_call():
+            p.write_lines(givenLines, encoding, linesep=None)
+            p.write_lines(givenLines, encoding, linesep=None, append=True)
         # Check the result.
         expectedBytes = 2 * given.encode(encoding)
         assert p.bytes() == expectedBytes
